@@ -67,7 +67,6 @@ function defineCommonExtensionSymbols(apiPrivate)
         PanelSearch: "panel-search-",
         ResourceAdded: "resource-added",
         ResourceContentCommitted: "resource-content-committed",
-        TimelineEventRecorded: "timeline-event-recorded",
         ViewShown: "view-shown-",
         ViewHidden: "view-hidden-"
     };
@@ -108,6 +107,7 @@ function defineCommonExtensionSymbols(apiPrivate)
 /**
  * @param {number} injectedScriptId
  * @return {!Object}
+ * @suppressGlobalPropertiesCheck
  */
 function injectedExtensionAPI(injectedScriptId)
 {
@@ -190,7 +190,6 @@ function InspectorExtensionAPI()
     this.panels = new Panels();
     this.network = new Network();
     defineDeprecatedProperty(this, "webInspector", "resources", "network");
-    this.timeline = new Timeline();
     this.console = new ConsoleAPI();
 }
 
@@ -443,7 +442,6 @@ var ExtensionSidebarPane = declareInterfaceClass(ExtensionSidebarPaneImpl);
 var PanelWithSidebar = declareInterfaceClass(PanelWithSidebarImpl);
 var Request = declareInterfaceClass(RequestImpl);
 var Resource = declareInterfaceClass(ResourceImpl);
-var Timeline = declareInterfaceClass(TimelineImpl);
 
 /**
  * @constructor
@@ -838,14 +836,6 @@ ResourceImpl.prototype = {
     }
 }
 
-/**
- * @constructor
- */
-function TimelineImpl()
-{
-    this.onEventRecorded = new EventSink(events.TimelineEventRecorded);
-}
-
 var keyboardEventRequestQueue = [];
 var forwardTimer = null;
 
@@ -905,6 +895,7 @@ function ExtensionServerClient()
 
 ExtensionServerClient.prototype = {
     /**
+     * @param {!Object} message
      * @param {function()=} callback
      */
     sendRequest: function(message, callback)
@@ -965,7 +956,7 @@ ExtensionServerClient.prototype = {
     }
 }
 
-function populateInterfaceClass(interface, implementation)
+function populateInterfaceClass(interfaze, implementation)
 {
     for (var member in implementation) {
         if (member.charAt(0) === "_")
@@ -977,11 +968,11 @@ function populateInterfaceClass(interface, implementation)
         if (!descriptor)
             continue;
         if (typeof descriptor.value === "function")
-            interface[member] = descriptor.value.bind(implementation);
+            interfaze[member] = descriptor.value.bind(implementation);
         else if (typeof descriptor.get === "function")
-            interface.__defineGetter__(member, descriptor.get.bind(implementation));
+            interfaze.__defineGetter__(member, descriptor.get.bind(implementation));
         else
-            Object.defineProperty(interface, member, descriptor);
+            Object.defineProperty(interfaze, member, descriptor);
     }
 }
 
